## История изменений

**0.0.3**
- Убрана зависимость от BaseEnumerate
- Изменено пространство имен c Ext3 на Ext
- В типы операции SQL добавлены COMMIT и SAVEPOINT
- Добавлен вывод информации о неизвестной операции SQL
- Изменен алгоритм генерации uuid для уменьшения размера лога
- Добавлен id пользователя в параметры логирования
- Добавлены метрики памяти процесса в параметры логирования (экспериментально)
- Добавлен pid процесса в параметры логирования


**0.0.2**
- Добавлено логирование количества SQL-запросов в разрезе типов на клиенте
- Добавлен подсчет количества sql-запросов в разрезе типов (select, insert, update, delete)
- При отключенном логировании на стороне клиента - заголовки http больше не отправлюятся, чтобы сократить размер ответа
- В метрики добавлен подсчет количества SQL запросов
- В метрики добавлен подсчет времени работы приложения без учета sql запросов
- В подсчет времени sql добавлен учет времени commit
- Исправлена сборка статики при создании пакета
- Обновлена информация по пакете